==> hadoop-3.2.2-src.tar.gz: hadoop-3.2.2-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-server/hadoop-yarn-server-nodemanager/src/main/java/org/apache/hadoop/yarn/server/nodemanager/containermanager/linux/resources/NetworkTagMappingManagerFactory.java <==
/*
 * *
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements. See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership. The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License. You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * /
 */

package org.apache.hadoop.yarn.server.nodemanager.containermanager.linux.resources;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.util.ReflectionUtils;
import org.apache.hadoop.yarn.conf.YarnConfiguration;

/**
 * Use {@code NetworkTagMappingManagerFactory} to get the correct
 * {@link NetworkTagMappingManager}.
 *
 */
public final class NetworkTagMappingManagerFactory {
  private static final Log LOG = LogFactory.getLog(
      NetworkTagMappingManagerFactory.class);

  private NetworkTagMappingManagerFactory() {}

  public static NetworkTagMappingManager getManager(Configuration conf) {
    Class<? extends NetworkTagMappingManager> managerClass =
        conf.getClass(YarnConfiguration.NM_NETWORK_TAG_MAPPING_MANAGER,
            NetworkTagMappingJsonManager.class,
            NetworkTagMappingManager.class);
    LOG.info("Using NetworkTagMappingManager implementation - "
        + managerClass);
    return ReflectionUtils.newInstance(managerClass, conf);
  }
}

==> hadoop-3.4.1-src.tar.gz: hadoop-3.4.1-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-server/hadoop-yarn-server-nodemanager/src/main/java/org/apache/hadoop/yarn/server/nodemanager/containermanager/linux/resources/NetworkTagMappingManagerFactory.java <==
/*
 * *
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements. See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership. The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License. You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * /
 */

package org.apache.hadoop.yarn.server.nodemanager.containermanager.linux.resources;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.util.ReflectionUtils;
import org.apache.hadoop.yarn.conf.YarnConfiguration;

/**
 * Use {@code NetworkTagMappingManagerFactory} to get the correct
 * {@link NetworkTagMappingManager}.
 *
 */
public final class NetworkTagMappingManagerFactory {
  private static final Logger LOG = LoggerFactory.getLogger(
      NetworkTagMappingManagerFactory.class);

  private NetworkTagMappingManagerFactory() {}

  public static NetworkTagMappingManager getManager(Configuration conf) {
    Class<? extends NetworkTagMappingManager> managerClass =
        conf.getClass(YarnConfiguration.NM_NETWORK_TAG_MAPPING_MANAGER,
            NetworkTagMappingJsonManager.class,
            NetworkTagMappingManager.class);
    LOG.info("Using NetworkTagMappingManager implementation - "
        + managerClass);
    return ReflectionUtils.newInstance(managerClass, conf);
  }
}
